//------------------------------------------------------------------------------
// <auto-generated />
//
// This file was automatically generated by SWIG (https://www.swig.org).
// Version 4.4.1
//
// Do not make changes to this file unless you know what you are doing - modify
// the SWIG interface file instead.
//------------------------------------------------------------------------------

namespace gv {

class gvPINVOKE {

  protected class SWIGExceptionHelper {

    public delegate void ExceptionDelegate(string message);
    public delegate void ExceptionArgumentDelegate(string message, string paramName);

    static ExceptionDelegate applicationDelegate = new ExceptionDelegate(SetPendingApplicationException);
    static ExceptionDelegate arithmeticDelegate = new ExceptionDelegate(SetPendingArithmeticException);
    static ExceptionDelegate divideByZeroDelegate = new ExceptionDelegate(SetPendingDivideByZeroException);
    static ExceptionDelegate indexOutOfRangeDelegate = new ExceptionDelegate(SetPendingIndexOutOfRangeException);
    static ExceptionDelegate invalidCastDelegate = new ExceptionDelegate(SetPendingInvalidCastException);
    static ExceptionDelegate invalidOperationDelegate = new ExceptionDelegate(SetPendingInvalidOperationException);
    static ExceptionDelegate ioDelegate = new ExceptionDelegate(SetPendingIOException);
    static ExceptionDelegate nullReferenceDelegate = new ExceptionDelegate(SetPendingNullReferenceException);
    static ExceptionDelegate outOfMemoryDelegate = new ExceptionDelegate(SetPendingOutOfMemoryException);
    static ExceptionDelegate overflowDelegate = new ExceptionDelegate(SetPendingOverflowException);
    static ExceptionDelegate systemDelegate = new ExceptionDelegate(SetPendingSystemException);

    static ExceptionArgumentDelegate argumentDelegate = new ExceptionArgumentDelegate(SetPendingArgumentException);
    static ExceptionArgumentDelegate argumentNullDelegate = new ExceptionArgumentDelegate(SetPendingArgumentNullException);
    static ExceptionArgumentDelegate argumentOutOfRangeDelegate = new ExceptionArgumentDelegate(SetPendingArgumentOutOfRangeException);

    [global::System.Runtime.InteropServices.DllImport("gv", EntryPoint="SWIGRegisterExceptionCallbacks_gv")]
    public static extern void SWIGRegisterExceptionCallbacks_gv(
                                ExceptionDelegate applicationDelegate,
                                ExceptionDelegate arithmeticDelegate,
                                ExceptionDelegate divideByZeroDelegate, 
                                ExceptionDelegate indexOutOfRangeDelegate, 
                                ExceptionDelegate invalidCastDelegate,
                                ExceptionDelegate invalidOperationDelegate,
                                ExceptionDelegate ioDelegate,
                                ExceptionDelegate nullReferenceDelegate,
                                ExceptionDelegate outOfMemoryDelegate, 
                                ExceptionDelegate overflowDelegate, 
                                ExceptionDelegate systemExceptionDelegate);

    [global::System.Runtime.InteropServices.DllImport("gv", EntryPoint="SWIGRegisterExceptionArgumentCallbacks_gv")]
    public static extern void SWIGRegisterExceptionCallbacksArgument_gv(
                                ExceptionArgumentDelegate argumentDelegate,
                                ExceptionArgumentDelegate argumentNullDelegate,
                                ExceptionArgumentDelegate argumentOutOfRangeDelegate);

    static void SetPendingApplicationException(string message) {
      SWIGPendingException.Set(new global::System.ApplicationException(message, SWIGPendingException.Retrieve()));
    }
    static void SetPendingArithmeticException(string message) {
      SWIGPendingException.Set(new global::System.ArithmeticException(message, SWIGPendingException.Retrieve()));
    }
    static void SetPendingDivideByZeroException(string message) {
      SWIGPendingException.Set(new global::System.DivideByZeroException(message, SWIGPendingException.Retrieve()));
    }
    static void SetPendingIndexOutOfRangeException(string message) {
      SWIGPendingException.Set(new global::System.IndexOutOfRangeException(message, SWIGPendingException.Retrieve()));
    }
    static void SetPendingInvalidCastException(string message) {
      SWIGPendingException.Set(new global::System.InvalidCastException(message, SWIGPendingException.Retrieve()));
    }
    static void SetPendingInvalidOperationException(string message) {
      SWIGPendingException.Set(new global::System.InvalidOperationException(message, SWIGPendingException.Retrieve()));
    }
    static void SetPendingIOException(string message) {
      SWIGPendingException.Set(new global::System.IO.IOException(message, SWIGPendingException.Retrieve()));
    }
    static void SetPendingNullReferenceException(string message) {
      SWIGPendingException.Set(new global::System.NullReferenceException(message, SWIGPendingException.Retrieve()));
    }
    static void SetPendingOutOfMemoryException(string message) {
      SWIGPendingException.Set(new global::System.OutOfMemoryException(message, SWIGPendingException.Retrieve()));
    }
    static void SetPendingOverflowException(string message) {
      SWIGPendingException.Set(new global::System.OverflowException(message, SWIGPendingException.Retrieve()));
    }
    static void SetPendingSystemException(string message) {
      SWIGPendingException.Set(new global::System.SystemException(message, SWIGPendingException.Retrieve()));
    }

    static void SetPendingArgumentException(string message, string paramName) {
      SWIGPendingException.Set(new global::System.ArgumentException(message, paramName, SWIGPendingException.Retrieve()));
    }
    static void SetPendingArgumentNullException(string message, string paramName) {
      global::System.Exception e = SWIGPendingException.Retrieve();
      if (e != null) message = message + " Inner Exception: " + e.Message;
      SWIGPendingException.Set(new global::System.ArgumentNullException(paramName, message));
    }
    static void SetPendingArgumentOutOfRangeException(string message, string paramName) {
      global::System.Exception e = SWIGPendingException.Retrieve();
      if (e != null) message = message + " Inner Exception: " + e.Message;
      SWIGPendingException.Set(new global::System.ArgumentOutOfRangeException(paramName, message));
    }

    static SWIGExceptionHelper() {
      SWIGRegisterExceptionCallbacks_gv(
                                applicationDelegate,
                                arithmeticDelegate,
                                divideByZeroDelegate,
                                indexOutOfRangeDelegate,
                                invalidCastDelegate,
                                invalidOperationDelegate,
                                ioDelegate,
                                nullReferenceDelegate,
                                outOfMemoryDelegate,
                                overflowDelegate,
                                systemDelegate);

      SWIGRegisterExceptionCallbacksArgument_gv(
                                argumentDelegate,
                                argumentNullDelegate,
                                argumentOutOfRangeDelegate);
    }
  }

  protected static SWIGExceptionHelper swigExceptionHelper = new SWIGExceptionHelper();

  public class SWIGPendingException {
    [global::System.ThreadStatic]
    private static global::System.Exception pendingException = null;
    private static int numExceptionsPending = 0;
    private static global::System.Object exceptionsLock = null;

    public static bool Pending {
      get {
        bool pending = false;
        if (numExceptionsPending > 0)
          if (pendingException != null)
            pending = true;
        return pending;
      } 
    }

    public static void Set(global::System.Exception e) {
      if (pendingException != null)
        throw new global::System.ApplicationException("FATAL: An earlier pending exception from unmanaged code was missed and thus not thrown (" + pendingException.ToString() + ")", e);
      pendingException = e;
      lock(exceptionsLock) {
        numExceptionsPending++;
      }
    }

    public static global::System.Exception Retrieve() {
      global::System.Exception e = null;
      if (numExceptionsPending > 0) {
        if (pendingException != null) {
          e = pendingException;
          pendingException = null;
          lock(exceptionsLock) {
            numExceptionsPending--;
          }
        }
      }
      return e;
    }

    static SWIGPendingException() {
      exceptionsLock = new global::System.Object();
    }
  }


  protected class SWIGStringHelper {

    public delegate string SWIGStringDelegate(string message);
    static SWIGStringDelegate stringDelegate = new SWIGStringDelegate(CreateString);

    [global::System.Runtime.InteropServices.DllImport("gv", EntryPoint="SWIGRegisterStringCallback_gv")]
    public static extern void SWIGRegisterStringCallback_gv(SWIGStringDelegate stringDelegate);

    static string CreateString(string cString) {
      return cString;
    }

    static SWIGStringHelper() {
      SWIGRegisterStringCallback_gv(stringDelegate);
    }
  }

  static protected SWIGStringHelper swigStringHelper = new SWIGStringHelper();


  public class SWIGStringWithLengthHelper {

    [global::System.Runtime.InteropServices.DllImport("gv", EntryPoint="SWIG_csharp_string_to_c")]
    private static extern global::System.IntPtr SWIG_csharp_string_to_c0(int size, int len, [global::System.Runtime.InteropServices.In,global::System.Runtime.InteropServices.MarshalAs(global::System.Runtime.InteropServices.UnmanagedType.LPStr, SizeParamIndex=0)] string str);

    [global::System.Runtime.InteropServices.DllImport("gv", EntryPoint="SWIG_csharp_string_size")]
    private static extern int SWIG_csharp_string_size(global::System.IntPtr str);

    [global::System.Runtime.InteropServices.DllImport("gv", EntryPoint="SWIG_csharp_string_str")]
    private static extern global::System.IntPtr SWIG_csharp_string_str(global::System.IntPtr str);

    public static global::System.IntPtr SWIG_csharp_string_to_c(string str) {
      if (str == null)
        return global::System.IntPtr.Zero;
      global::System.Text.Encoding utf8 = global::System.Text.Encoding.UTF8;
      return SWIG_csharp_string_to_c0(utf8.GetByteCount(str), str.Length, str);
    }

    public static string SWIG_c_to_csharp_string(global::System.IntPtr str) {
      int size = SWIG_csharp_string_size(str);
      if (size > 0) {
        global::System.IntPtr s = SWIG_csharp_string_str(str);
        byte[] b = new byte[size];
        global::System.Runtime.InteropServices.Marshal.Copy(s, b, 0, size);
        global::System.Text.Encoding utf8 = global::System.Text.Encoding.UTF8;
        return utf8.GetString(b);
      }
      return null;
    }
  }


  static gvPINVOKE() {
  }


  [global::System.Runtime.InteropServices.DllImport("gv", EntryPoint="CSharp_gv_graph__SWIG_0")]
  public static extern global::System.IntPtr graph__SWIG_0(string jarg1);

  [global::System.Runtime.InteropServices.DllImport("gv", EntryPoint="CSharp_gv_digraph")]
  public static extern global::System.IntPtr digraph(string jarg1);

  [global::System.Runtime.InteropServices.DllImport("gv", EntryPoint="CSharp_gv_strictgraph")]
  public static extern global::System.IntPtr strictgraph(string jarg1);

  [global::System.Runtime.InteropServices.DllImport("gv", EntryPoint="CSharp_gv_strictdigraph")]
  public static extern global::System.IntPtr strictdigraph(string jarg1);

  [global::System.Runtime.InteropServices.DllImport("gv", EntryPoint="CSharp_gv_readstring")]
  public static extern global::System.IntPtr readstring(string jarg1);

  [global::System.Runtime.InteropServices.DllImport("gv", EntryPoint="CSharp_gv_read__SWIG_0")]
  public static extern global::System.IntPtr read__SWIG_0(string jarg1);

  [global::System.Runtime.InteropServices.DllImport("gv", EntryPoint="CSharp_gv_read__SWIG_1")]
  public static extern global::System.IntPtr read__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("gv", EntryPoint="CSharp_gv_graph__SWIG_1")]
  public static extern global::System.IntPtr graph__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, string jarg2);

  [global::System.Runtime.InteropServices.DllImport("gv", EntryPoint="CSharp_gv_node")]
  public static extern global::System.IntPtr node(global::System.Runtime.InteropServices.HandleRef jarg1, string jarg2);

  [global::System.Runtime.InteropServices.DllImport("gv", EntryPoint="CSharp_gv_edge__SWIG_0")]
  public static extern global::System.IntPtr edge__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("gv", EntryPoint="CSharp_gv_edge__SWIG_1")]
  public static extern global::System.IntPtr edge__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, string jarg2);

  [global::System.Runtime.InteropServices.DllImport("gv", EntryPoint="CSharp_gv_edge__SWIG_2")]
  public static extern global::System.IntPtr edge__SWIG_2(string jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("gv", EntryPoint="CSharp_gv_edge__SWIG_3")]
  public static extern global::System.IntPtr edge__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, string jarg2, string jarg3);

  [global::System.Runtime.InteropServices.DllImport("gv", EntryPoint="CSharp_gv_setv__SWIG_0")]
  public static extern string setv__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, string jarg2, string jarg3);

  [global::System.Runtime.InteropServices.DllImport("gv", EntryPoint="CSharp_gv_setv__SWIG_1")]
  public static extern string setv__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, string jarg2, string jarg3);

  [global::System.Runtime.InteropServices.DllImport("gv", EntryPoint="CSharp_gv_setv__SWIG_2")]
  public static extern string setv__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, string jarg2, string jarg3);

  [global::System.Runtime.InteropServices.DllImport("gv", EntryPoint="CSharp_gv_setv__SWIG_3")]
  public static extern string setv__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, string jarg3);

  [global::System.Runtime.InteropServices.DllImport("gv", EntryPoint="CSharp_gv_setv__SWIG_4")]
  public static extern string setv__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, string jarg3);

  [global::System.Runtime.InteropServices.DllImport("gv", EntryPoint="CSharp_gv_setv__SWIG_5")]
  public static extern string setv__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, string jarg3);

  [global::System.Runtime.InteropServices.DllImport("gv", EntryPoint="CSharp_gv_getv__SWIG_0")]
  public static extern string getv__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, string jarg2);

  [global::System.Runtime.InteropServices.DllImport("gv", EntryPoint="CSharp_gv_getv__SWIG_1")]
  public static extern string getv__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, string jarg2);

  [global::System.Runtime.InteropServices.DllImport("gv", EntryPoint="CSharp_gv_getv__SWIG_2")]
  public static extern string getv__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, string jarg2);

  [global::System.Runtime.InteropServices.DllImport("gv", EntryPoint="CSharp_gv_getv__SWIG_3")]
  public static extern string getv__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("gv", EntryPoint="CSharp_gv_getv__SWIG_4")]
  public static extern string getv__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("gv", EntryPoint="CSharp_gv_getv__SWIG_5")]
  public static extern string getv__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("gv", EntryPoint="CSharp_gv_nameof__SWIG_0")]
  public static extern string nameof__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("gv", EntryPoint="CSharp_gv_nameof__SWIG_1")]
  public static extern string nameof__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("gv", EntryPoint="CSharp_gv_nameof__SWIG_2")]
  public static extern string nameof__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("gv", EntryPoint="CSharp_gv_findsubg")]
  public static extern global::System.IntPtr findsubg(global::System.Runtime.InteropServices.HandleRef jarg1, string jarg2);

  [global::System.Runtime.InteropServices.DllImport("gv", EntryPoint="CSharp_gv_findnode")]
  public static extern global::System.IntPtr findnode(global::System.Runtime.InteropServices.HandleRef jarg1, string jarg2);

  [global::System.Runtime.InteropServices.DllImport("gv", EntryPoint="CSharp_gv_findedge")]
  public static extern global::System.IntPtr findedge(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("gv", EntryPoint="CSharp_gv_findattr__SWIG_0")]
  public static extern global::System.IntPtr findattr__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, string jarg2);

  [global::System.Runtime.InteropServices.DllImport("gv", EntryPoint="CSharp_gv_findattr__SWIG_1")]
  public static extern global::System.IntPtr findattr__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, string jarg2);

  [global::System.Runtime.InteropServices.DllImport("gv", EntryPoint="CSharp_gv_findattr__SWIG_2")]
  public static extern global::System.IntPtr findattr__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, string jarg2);

  [global::System.Runtime.InteropServices.DllImport("gv", EntryPoint="CSharp_gv_headof")]
  public static extern global::System.IntPtr headof(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("gv", EntryPoint="CSharp_gv_tailof")]
  public static extern global::System.IntPtr tailof(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("gv", EntryPoint="CSharp_gv_graphof__SWIG_0")]
  public static extern global::System.IntPtr graphof__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("gv", EntryPoint="CSharp_gv_graphof__SWIG_1")]
  public static extern global::System.IntPtr graphof__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("gv", EntryPoint="CSharp_gv_graphof__SWIG_2")]
  public static extern global::System.IntPtr graphof__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("gv", EntryPoint="CSharp_gv_rootof")]
  public static extern global::System.IntPtr rootof(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("gv", EntryPoint="CSharp_gv_protonode")]
  public static extern global::System.IntPtr protonode(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("gv", EntryPoint="CSharp_gv_protoedge")]
  public static extern global::System.IntPtr protoedge(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("gv", EntryPoint="CSharp_gv_ok__SWIG_0")]
  public static extern bool ok__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("gv", EntryPoint="CSharp_gv_ok__SWIG_1")]
  public static extern bool ok__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("gv", EntryPoint="CSharp_gv_ok__SWIG_2")]
  public static extern bool ok__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("gv", EntryPoint="CSharp_gv_ok__SWIG_3")]
  public static extern bool ok__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("gv", EntryPoint="CSharp_gv_firstsubg")]
  public static extern global::System.IntPtr firstsubg(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("gv", EntryPoint="CSharp_gv_nextsubg")]
  public static extern global::System.IntPtr nextsubg(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("gv", EntryPoint="CSharp_gv_firstsupg")]
  public static extern global::System.IntPtr firstsupg(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("gv", EntryPoint="CSharp_gv_nextsupg")]
  public static extern global::System.IntPtr nextsupg(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("gv", EntryPoint="CSharp_gv_firstedge__SWIG_0")]
  public static extern global::System.IntPtr firstedge__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("gv", EntryPoint="CSharp_gv_nextedge__SWIG_0")]
  public static extern global::System.IntPtr nextedge__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("gv", EntryPoint="CSharp_gv_firstout__SWIG_0")]
  public static extern global::System.IntPtr firstout__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("gv", EntryPoint="CSharp_gv_nextout__SWIG_0")]
  public static extern global::System.IntPtr nextout__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("gv", EntryPoint="CSharp_gv_firstedge__SWIG_1")]
  public static extern global::System.IntPtr firstedge__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("gv", EntryPoint="CSharp_gv_nextedge__SWIG_1")]
  public static extern global::System.IntPtr nextedge__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("gv", EntryPoint="CSharp_gv_firstout__SWIG_1")]
  public static extern global::System.IntPtr firstout__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("gv", EntryPoint="CSharp_gv_nextout__SWIG_1")]
  public static extern global::System.IntPtr nextout__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("gv", EntryPoint="CSharp_gv_firsthead")]
  public static extern global::System.IntPtr firsthead(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("gv", EntryPoint="CSharp_gv_nexthead")]
  public static extern global::System.IntPtr nexthead(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("gv", EntryPoint="CSharp_gv_firstin__SWIG_0")]
  public static extern global::System.IntPtr firstin__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("gv", EntryPoint="CSharp_gv_nextin__SWIG_0")]
  public static extern global::System.IntPtr nextin__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("gv", EntryPoint="CSharp_gv_firstin__SWIG_1")]
  public static extern global::System.IntPtr firstin__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("gv", EntryPoint="CSharp_gv_nextin__SWIG_1")]
  public static extern global::System.IntPtr nextin__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("gv", EntryPoint="CSharp_gv_firsttail")]
  public static extern global::System.IntPtr firsttail(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("gv", EntryPoint="CSharp_gv_nexttail")]
  public static extern global::System.IntPtr nexttail(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("gv", EntryPoint="CSharp_gv_firstnode__SWIG_0")]
  public static extern global::System.IntPtr firstnode__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("gv", EntryPoint="CSharp_gv_nextnode__SWIG_0")]
  public static extern global::System.IntPtr nextnode__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("gv", EntryPoint="CSharp_gv_firstnode__SWIG_1")]
  public static extern global::System.IntPtr firstnode__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("gv", EntryPoint="CSharp_gv_nextnode__SWIG_1")]
  public static extern global::System.IntPtr nextnode__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("gv", EntryPoint="CSharp_gv_firstattr__SWIG_0")]
  public static extern global::System.IntPtr firstattr__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("gv", EntryPoint="CSharp_gv_nextattr__SWIG_0")]
  public static extern global::System.IntPtr nextattr__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("gv", EntryPoint="CSharp_gv_firstattr__SWIG_1")]
  public static extern global::System.IntPtr firstattr__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("gv", EntryPoint="CSharp_gv_nextattr__SWIG_1")]
  public static extern global::System.IntPtr nextattr__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("gv", EntryPoint="CSharp_gv_firstattr__SWIG_2")]
  public static extern global::System.IntPtr firstattr__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("gv", EntryPoint="CSharp_gv_nextattr__SWIG_2")]
  public static extern global::System.IntPtr nextattr__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("gv", EntryPoint="CSharp_gv_rm__SWIG_0")]
  public static extern bool rm__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("gv", EntryPoint="CSharp_gv_rm__SWIG_1")]
  public static extern bool rm__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("gv", EntryPoint="CSharp_gv_rm__SWIG_2")]
  public static extern bool rm__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("gv", EntryPoint="CSharp_gv_layout")]
  public static extern bool layout(global::System.Runtime.InteropServices.HandleRef jarg1, string jarg2);

  [global::System.Runtime.InteropServices.DllImport("gv", EntryPoint="CSharp_gv_render__SWIG_0")]
  public static extern bool render__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("gv", EntryPoint="CSharp_gv_render__SWIG_1")]
  public static extern bool render__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, string jarg2);

  [global::System.Runtime.InteropServices.DllImport("gv", EntryPoint="CSharp_gv_render__SWIG_2")]
  public static extern bool render__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, string jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("gv", EntryPoint="CSharp_gv_render__SWIG_3")]
  public static extern bool render__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, string jarg2, string jarg3);

  [global::System.Runtime.InteropServices.DllImport("gv", EntryPoint="CSharp_gv_renderresult")]
  public static extern void renderresult(global::System.Runtime.InteropServices.HandleRef jarg1, string jarg2, string jarg3);

  [global::System.Runtime.InteropServices.DllImport("gv", EntryPoint="CSharp_gv_renderchannel")]
  public static extern bool renderchannel(global::System.Runtime.InteropServices.HandleRef jarg1, string jarg2, string jarg3);

  [global::System.Runtime.InteropServices.DllImport("gv", EntryPoint="CSharp_gv_renderdata")]
  public static extern string renderdata(global::System.Runtime.InteropServices.HandleRef jarg1, string jarg2);

  [global::System.Runtime.InteropServices.DllImport("gv", EntryPoint="CSharp_gv_write__SWIG_0")]
  public static extern bool write__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, string jarg2);

  [global::System.Runtime.InteropServices.DllImport("gv", EntryPoint="CSharp_gv_write__SWIG_1")]
  public static extern bool write__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("gv", EntryPoint="CSharp_gv_tred")]
  public static extern bool tred(global::System.Runtime.InteropServices.HandleRef jarg1);
}

}
